@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2021-2022 -- leonerd@leonerd.org.uk
 
-package XS::Parse::Keyword 0.36;
+package XS::Parse::Keyword 0.37;
 
 use v5.14;
 use warnings;
@@ -563,6 +563,31 @@ I<atomic, emits nothing.>
 Calls the core perl C<intro_my()> function immediately. No input is consumed
 and no output value is generated. This is often useful after C<XPK_LEXVAR_MY>.
 
+=head2 XPK_WARNING
+
+I<atomic, emits nothing.>
+
+   XPK_WARNING("message here")
+
+Emits a warning by calling the core perl C<warn()> function on the given
+string literal. This is equivalent to simply calling C<warn()> from the build
+function, except that it is emitted immediately at parse time, so line
+numbering will be more accurate. Also, by placing it as part of an optional or
+choice sequence, the warning will only be emitted conditionally if that part
+of the grammar structure is encountered.
+
+=head2 XPK_WARNING_...
+
+Several variants of C<XPK_WARNING> exist that are conditional on particular
+warning categories being enabled. These are ones that are likely to be useful
+at parse time:
+
+   XPK_WARNING_AMBIGUOUS
+   XPK_WARNING_DEPRECATED
+   XPK_WARNING_EXPERIMENTAL
+   XPK_WARNING_PRECEDENCE
+   XPK_WARNING_SYNTAX
+
 =head2 XPK_SEQUENCE
 
 I<structural, might support probe, emits nothing.>
