@@ -414,6 +414,15 @@ static void parse_piece(pTHX_ SV *argsv, size_t *argidx, const struct XSParseKey
       parse_autosemi();
       return;
 
+    case XS_PARSE_KEYWORD_WARNING:
+    {
+      int warnbit = piece->type >> 24;
+      if(warnbit && !ckWARN(warnbit))
+        return;
+      warn(piece->u.str);
+      return;
+    }
+
     case XS_PARSE_KEYWORD_FAILURE:
       yycroak(piece->u.str);
       NOT_REACHED;
